# PLUGIN UNDER DEVELOPMENT

# Netbox Nbrisk
NIST 800-30 Risk Management for [Netbox](https://github.com/netbox-community/netbox)

## Compatibility

This plugin in compatible with [NetBox](https://netbox.readthedocs.org/) 3.4.0 and later.

## Installation

Not ready

## Configuration

## Screenshots

### Vulnerability View

![image](https://user-images.githubusercontent.com/16046203/214468549-afc2de89-2d1e-412e-96d5-839ac47d4d9e.png)

### Affected Assets

![image](https://user-images.githubusercontent.com/16046203/214468616-4d45b1ff-9887-43b9-9c17-0047ff5a5f02.png)

### Device Vulnerabilities

![image](https://user-images.githubusercontent.com/16046203/214468700-81d21799-8381-4fca-a9bf-204a41211736.png)

